# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'windows/window1.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1000, 600)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setMouseTracking(True)
        self.centralwidget.setObjectName("centralwidget")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_4.setSpacing(0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.mainWidget = QtWidgets.QWidget(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mainWidget.sizePolicy().hasHeightForWidth())
        self.mainWidget.setSizePolicy(sizePolicy)
        self.mainWidget.setMouseTracking(True)
        self.mainWidget.setObjectName("mainWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.mainWidget)
        self.verticalLayout.setContentsMargins(2, 2, 2, 2)
        self.verticalLayout.setSpacing(4)
        self.verticalLayout.setObjectName("verticalLayout")
        self.menuFrame = QtWidgets.QFrame(self.mainWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.menuFrame.sizePolicy().hasHeightForWidth())
        self.menuFrame.setSizePolicy(sizePolicy)
        self.menuFrame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.menuFrame.setObjectName("menuFrame")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.menuFrame)
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(4)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btnUndo = QtWidgets.QPushButton(self.menuFrame)
        self.btnUndo.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnUndo.sizePolicy().hasHeightForWidth())
        self.btnUndo.setSizePolicy(sizePolicy)
        self.btnUndo.setMaximumSize(QtCore.QSize(25, 25))
        self.btnUndo.setBaseSize(QtCore.QSize(32, 32))
        self.btnUndo.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/undo.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnUndo.setIcon(icon)
        self.btnUndo.setIconSize(QtCore.QSize(16, 16))
        self.btnUndo.setFlat(True)
        self.btnUndo.setObjectName("btnUndo")
        self.horizontalLayout.addWidget(self.btnUndo)
        self.btnRedo = QtWidgets.QPushButton(self.menuFrame)
        self.btnRedo.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnRedo.sizePolicy().hasHeightForWidth())
        self.btnRedo.setSizePolicy(sizePolicy)
        self.btnRedo.setMaximumSize(QtCore.QSize(25, 25))
        self.btnRedo.setBaseSize(QtCore.QSize(32, 32))
        self.btnRedo.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/redo.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnRedo.setIcon(icon1)
        self.btnRedo.setIconSize(QtCore.QSize(16, 16))
        self.btnRedo.setFlat(True)
        self.btnRedo.setObjectName("btnRedo")
        self.horizontalLayout.addWidget(self.btnRedo)
        self.btnLoadFile = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnLoadFile.sizePolicy().hasHeightForWidth())
        self.btnLoadFile.setSizePolicy(sizePolicy)
        self.btnLoadFile.setMaximumSize(QtCore.QSize(25, 25))
        self.btnLoadFile.setBaseSize(QtCore.QSize(32, 32))
        self.btnLoadFile.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/android-folder-open.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnLoadFile.setIcon(icon2)
        self.btnLoadFile.setIconSize(QtCore.QSize(16, 16))
        self.btnLoadFile.setFlat(True)
        self.btnLoadFile.setObjectName("btnLoadFile")
        self.horizontalLayout.addWidget(self.btnLoadFile)
        self.btnSave = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnSave.sizePolicy().hasHeightForWidth())
        self.btnSave.setSizePolicy(sizePolicy)
        self.btnSave.setMaximumSize(QtCore.QSize(25, 25))
        self.btnSave.setBaseSize(QtCore.QSize(32, 32))
        self.btnSave.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/save.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnSave.setIcon(icon3)
        self.btnSave.setIconSize(QtCore.QSize(16, 16))
        self.btnSave.setFlat(True)
        self.btnSave.setObjectName("btnSave")
        self.horizontalLayout.addWidget(self.btnSave)
        self.btnViewCode = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnViewCode.sizePolicy().hasHeightForWidth())
        self.btnViewCode.setSizePolicy(sizePolicy)
        self.btnViewCode.setMaximumSize(QtCore.QSize(24, 24))
        self.btnViewCode.setBaseSize(QtCore.QSize(20, 20))
        self.btnViewCode.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icons/code.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnViewCode.setIcon(icon4)
        self.btnViewCode.setIconSize(QtCore.QSize(16, 16))
        self.btnViewCode.setFlat(True)
        self.btnViewCode.setObjectName("btnViewCode")
        self.horizontalLayout.addWidget(self.btnViewCode)
        self.btnQuickScreenshot = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnQuickScreenshot.sizePolicy().hasHeightForWidth())
        self.btnQuickScreenshot.setSizePolicy(sizePolicy)
        self.btnQuickScreenshot.setMaximumSize(QtCore.QSize(25, 25))
        self.btnQuickScreenshot.setBaseSize(QtCore.QSize(32, 32))
        self.btnQuickScreenshot.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icons/android-camera.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnQuickScreenshot.setIcon(icon5)
        self.btnQuickScreenshot.setIconSize(QtCore.QSize(16, 16))
        self.btnQuickScreenshot.setFlat(True)
        self.btnQuickScreenshot.setObjectName("btnQuickScreenshot")
        self.horizontalLayout.addWidget(self.btnQuickScreenshot)
        spacerItem = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.btnDrawAxes = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnDrawAxes.sizePolicy().hasHeightForWidth())
        self.btnDrawAxes.setSizePolicy(sizePolicy)
        self.btnDrawAxes.setMaximumSize(QtCore.QSize(25, 25))
        self.btnDrawAxes.setBaseSize(QtCore.QSize(32, 32))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setBold(True)
        font.setWeight(75)
        self.btnDrawAxes.setFont(font)
        self.btnDrawAxes.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icons/plus-round.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnDrawAxes.setIcon(icon6)
        self.btnDrawAxes.setIconSize(QtCore.QSize(16, 16))
        self.btnDrawAxes.setCheckable(True)
        self.btnDrawAxes.setChecked(True)
        self.btnDrawAxes.setFlat(True)
        self.btnDrawAxes.setObjectName("btnDrawAxes")
        self.horizontalLayout.addWidget(self.btnDrawAxes)
        self.btnDrawGrid = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnDrawGrid.sizePolicy().hasHeightForWidth())
        self.btnDrawGrid.setSizePolicy(sizePolicy)
        self.btnDrawGrid.setMaximumSize(QtCore.QSize(25, 25))
        self.btnDrawGrid.setBaseSize(QtCore.QSize(32, 32))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setBold(True)
        font.setWeight(75)
        self.btnDrawGrid.setFont(font)
        self.btnDrawGrid.setText("")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icons/grid.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnDrawGrid.setIcon(icon7)
        self.btnDrawGrid.setIconSize(QtCore.QSize(16, 16))
        self.btnDrawGrid.setCheckable(True)
        self.btnDrawGrid.setChecked(False)
        self.btnDrawGrid.setFlat(True)
        self.btnDrawGrid.setObjectName("btnDrawGrid")
        self.horizontalLayout.addWidget(self.btnDrawGrid)
        self.btnSetZoom = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnSetZoom.sizePolicy().hasHeightForWidth())
        self.btnSetZoom.setSizePolicy(sizePolicy)
        self.btnSetZoom.setMaximumSize(QtCore.QSize(25, 25))
        self.btnSetZoom.setBaseSize(QtCore.QSize(32, 32))
        self.btnSetZoom.setText("")
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/icons/magnifying-glass.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnSetZoom.setIcon(icon8)
        self.btnSetZoom.setIconSize(QtCore.QSize(16, 16))
        self.btnSetZoom.setFlat(True)
        self.btnSetZoom.setObjectName("btnSetZoom")
        self.horizontalLayout.addWidget(self.btnSetZoom)
        self.btnPanCenter = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnPanCenter.sizePolicy().hasHeightForWidth())
        self.btnPanCenter.setSizePolicy(sizePolicy)
        self.btnPanCenter.setMaximumSize(QtCore.QSize(25, 25))
        self.btnPanCenter.setBaseSize(QtCore.QSize(32, 32))
        self.btnPanCenter.setText("")
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/icons/center.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnPanCenter.setIcon(icon9)
        self.btnPanCenter.setIconSize(QtCore.QSize(16, 16))
        self.btnPanCenter.setFlat(True)
        self.btnPanCenter.setObjectName("btnPanCenter")
        self.horizontalLayout.addWidget(self.btnPanCenter)
        self.btnResetPan = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnResetPan.sizePolicy().hasHeightForWidth())
        self.btnResetPan.setSizePolicy(sizePolicy)
        self.btnResetPan.setMaximumSize(QtCore.QSize(25, 25))
        self.btnResetPan.setBaseSize(QtCore.QSize(32, 32))
        self.btnResetPan.setText("")
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/icons/centerorigin.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnResetPan.setIcon(icon10)
        self.btnResetPan.setIconSize(QtCore.QSize(16, 16))
        self.btnResetPan.setFlat(True)
        self.btnResetPan.setObjectName("btnResetPan")
        self.horizontalLayout.addWidget(self.btnResetPan)
        self.btnAlignX = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnAlignX.sizePolicy().hasHeightForWidth())
        self.btnAlignX.setSizePolicy(sizePolicy)
        self.btnAlignX.setMaximumSize(QtCore.QSize(32, 25))
        self.btnAlignX.setBaseSize(QtCore.QSize(32, 32))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setBold(True)
        font.setWeight(75)
        self.btnAlignX.setFont(font)
        self.btnAlignX.setIconSize(QtCore.QSize(16, 16))
        self.btnAlignX.setCheckable(True)
        self.btnAlignX.setFlat(True)
        self.btnAlignX.setObjectName("btnAlignX")
        self.horizontalLayout.addWidget(self.btnAlignX)
        self.btnAlignY = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnAlignY.sizePolicy().hasHeightForWidth())
        self.btnAlignY.setSizePolicy(sizePolicy)
        self.btnAlignY.setMaximumSize(QtCore.QSize(32, 25))
        self.btnAlignY.setBaseSize(QtCore.QSize(32, 32))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setBold(True)
        font.setWeight(75)
        self.btnAlignY.setFont(font)
        self.btnAlignY.setIconSize(QtCore.QSize(16, 16))
        self.btnAlignY.setCheckable(True)
        self.btnAlignY.setFlat(True)
        self.btnAlignY.setObjectName("btnAlignY")
        self.horizontalLayout.addWidget(self.btnAlignY)
        spacerItem1 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.btnSelectEdit = QtWidgets.QPushButton(self.menuFrame)
        self.btnSelectEdit.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnSelectEdit.sizePolicy().hasHeightForWidth())
        self.btnSelectEdit.setSizePolicy(sizePolicy)
        self.btnSelectEdit.setMaximumSize(QtCore.QSize(25, 25))
        self.btnSelectEdit.setText("")
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/icons/edit.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnSelectEdit.setIcon(icon11)
        self.btnSelectEdit.setIconSize(QtCore.QSize(16, 16))
        self.btnSelectEdit.setCheckable(True)
        self.btnSelectEdit.setFlat(True)
        self.btnSelectEdit.setObjectName("btnSelectEdit")
        self.horizontalLayout.addWidget(self.btnSelectEdit)
        self.btnDeleteMode = QtWidgets.QPushButton(self.menuFrame)
        self.btnDeleteMode.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnDeleteMode.sizePolicy().hasHeightForWidth())
        self.btnDeleteMode.setSizePolicy(sizePolicy)
        self.btnDeleteMode.setMaximumSize(QtCore.QSize(25, 25))
        self.btnDeleteMode.setBaseSize(QtCore.QSize(32, 32))
        self.btnDeleteMode.setText("")
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/icons/android-delete.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnDeleteMode.setIcon(icon12)
        self.btnDeleteMode.setIconSize(QtCore.QSize(16, 16))
        self.btnDeleteMode.setCheckable(True)
        self.btnDeleteMode.setFlat(True)
        self.btnDeleteMode.setObjectName("btnDeleteMode")
        self.horizontalLayout.addWidget(self.btnDeleteMode)
        spacerItem2 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem2)
        self.btnPan = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnPan.sizePolicy().hasHeightForWidth())
        self.btnPan.setSizePolicy(sizePolicy)
        self.btnPan.setMaximumSize(QtCore.QSize(25, 25))
        self.btnPan.setBaseSize(QtCore.QSize(32, 32))
        self.btnPan.setText("")
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/icons/android-hand.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnPan.setIcon(icon13)
        self.btnPan.setIconSize(QtCore.QSize(16, 16))
        self.btnPan.setCheckable(True)
        self.btnPan.setFlat(True)
        self.btnPan.setObjectName("btnPan")
        self.horizontalLayout.addWidget(self.btnPan)
        self.btnTranslate = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnTranslate.sizePolicy().hasHeightForWidth())
        self.btnTranslate.setSizePolicy(sizePolicy)
        self.btnTranslate.setMaximumSize(QtCore.QSize(25, 25))
        self.btnTranslate.setBaseSize(QtCore.QSize(32, 32))
        self.btnTranslate.setText("")
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/icons/arrow-move.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnTranslate.setIcon(icon14)
        self.btnTranslate.setIconSize(QtCore.QSize(16, 16))
        self.btnTranslate.setCheckable(True)
        self.btnTranslate.setChecked(True)
        self.btnTranslate.setFlat(True)
        self.btnTranslate.setObjectName("btnTranslate")
        self.horizontalLayout.addWidget(self.btnTranslate)
        self.btnScale = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnScale.sizePolicy().hasHeightForWidth())
        self.btnScale.setSizePolicy(sizePolicy)
        self.btnScale.setMaximumSize(QtCore.QSize(25, 25))
        self.btnScale.setBaseSize(QtCore.QSize(32, 32))
        self.btnScale.setText("")
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/icons/arrow-resize.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnScale.setIcon(icon15)
        self.btnScale.setIconSize(QtCore.QSize(16, 16))
        self.btnScale.setCheckable(True)
        self.btnScale.setFlat(True)
        self.btnScale.setObjectName("btnScale")
        self.horizontalLayout.addWidget(self.btnScale)
        self.btnRotate = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnRotate.sizePolicy().hasHeightForWidth())
        self.btnRotate.setSizePolicy(sizePolicy)
        self.btnRotate.setMaximumSize(QtCore.QSize(25, 25))
        self.btnRotate.setBaseSize(QtCore.QSize(32, 32))
        self.btnRotate.setText("")
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/icons/android-refresh.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnRotate.setIcon(icon16)
        self.btnRotate.setIconSize(QtCore.QSize(16, 16))
        self.btnRotate.setCheckable(True)
        self.btnRotate.setFlat(True)
        self.btnRotate.setObjectName("btnRotate")
        self.horizontalLayout.addWidget(self.btnRotate)
        spacerItem3 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.btnAnchor = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnAnchor.sizePolicy().hasHeightForWidth())
        self.btnAnchor.setSizePolicy(sizePolicy)
        self.btnAnchor.setMaximumSize(QtCore.QSize(25, 25))
        self.btnAnchor.setBaseSize(QtCore.QSize(32, 32))
        self.btnAnchor.setText("")
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/icons/anchor.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnAnchor.setIcon(icon17)
        self.btnAnchor.setIconSize(QtCore.QSize(16, 16))
        self.btnAnchor.setCheckable(True)
        self.btnAnchor.setChecked(False)
        self.btnAnchor.setFlat(True)
        self.btnAnchor.setObjectName("btnAnchor")
        self.horizontalLayout.addWidget(self.btnAnchor)
        self.comboAnchor = QtWidgets.QComboBox(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboAnchor.sizePolicy().hasHeightForWidth())
        self.comboAnchor.setSizePolicy(sizePolicy)
        self.comboAnchor.setMinimumSize(QtCore.QSize(127, 0))
        self.comboAnchor.setMaximumSize(QtCore.QSize(127, 25))
        self.comboAnchor.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.comboAnchor.setEditable(False)
        self.comboAnchor.setInsertPolicy(QtWidgets.QComboBox.InsertAtCurrent)
        self.comboAnchor.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContentsOnFirstShow)
        self.comboAnchor.setIconSize(QtCore.QSize(0, 0))
        self.comboAnchor.setDuplicatesEnabled(False)
        self.comboAnchor.setFrame(False)
        self.comboAnchor.setModelColumn(0)
        self.comboAnchor.setObjectName("comboAnchor")
        self.comboAnchor.addItem("")
        self.comboAnchor.addItem("")
        self.comboAnchor.addItem("")
        self.comboAnchor.addItem("")
        self.comboAnchor.addItem("")
        self.comboAnchor.addItem("")
        self.comboAnchor.addItem("")
        self.horizontalLayout.addWidget(self.comboAnchor)
        self.btnToggleVisible = QtWidgets.QPushButton(self.menuFrame)
        self.btnToggleVisible.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnToggleVisible.sizePolicy().hasHeightForWidth())
        self.btnToggleVisible.setSizePolicy(sizePolicy)
        self.btnToggleVisible.setMaximumSize(QtCore.QSize(25, 25))
        self.btnToggleVisible.setBaseSize(QtCore.QSize(32, 32))
        self.btnToggleVisible.setText("")
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/icons/eye.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnToggleVisible.setIcon(icon18)
        self.btnToggleVisible.setIconSize(QtCore.QSize(16, 16))
        self.btnToggleVisible.setCheckable(False)
        self.btnToggleVisible.setFlat(True)
        self.btnToggleVisible.setObjectName("btnToggleVisible")
        self.horizontalLayout.addWidget(self.btnToggleVisible)
        self.btnCustTransform = QtWidgets.QPushButton(self.menuFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnCustTransform.sizePolicy().hasHeightForWidth())
        self.btnCustTransform.setSizePolicy(sizePolicy)
        self.btnCustTransform.setMaximumSize(QtCore.QSize(25, 25))
        self.btnCustTransform.setBaseSize(QtCore.QSize(32, 32))
        self.btnCustTransform.setText("")
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(":/icons/android-expand.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnCustTransform.setIcon(icon19)
        self.btnCustTransform.setIconSize(QtCore.QSize(16, 16))
        self.btnCustTransform.setFlat(True)
        self.btnCustTransform.setObjectName("btnCustTransform")
        self.horizontalLayout.addWidget(self.btnCustTransform)
        self.btnSendBackwards = QtWidgets.QPushButton(self.menuFrame)
        self.btnSendBackwards.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnSendBackwards.sizePolicy().hasHeightForWidth())
        self.btnSendBackwards.setSizePolicy(sizePolicy)
        self.btnSendBackwards.setMaximumSize(QtCore.QSize(25, 25))
        self.btnSendBackwards.setBaseSize(QtCore.QSize(32, 32))
        self.btnSendBackwards.setText("")
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(":/icons/chevron-with-circle-left.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnSendBackwards.setIcon(icon20)
        self.btnSendBackwards.setIconSize(QtCore.QSize(16, 16))
        self.btnSendBackwards.setFlat(True)
        self.btnSendBackwards.setObjectName("btnSendBackwards")
        self.horizontalLayout.addWidget(self.btnSendBackwards)
        self.btnSendForwards = QtWidgets.QPushButton(self.menuFrame)
        self.btnSendForwards.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnSendForwards.sizePolicy().hasHeightForWidth())
        self.btnSendForwards.setSizePolicy(sizePolicy)
        self.btnSendForwards.setMaximumSize(QtCore.QSize(25, 25))
        self.btnSendForwards.setBaseSize(QtCore.QSize(32, 32))
        self.btnSendForwards.setText("")
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(":/icons/chevron-with-circle-right.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnSendForwards.setIcon(icon21)
        self.btnSendForwards.setIconSize(QtCore.QSize(16, 16))
        self.btnSendForwards.setFlat(True)
        self.btnSendForwards.setObjectName("btnSendForwards")
        self.horizontalLayout.addWidget(self.btnSendForwards)
        spacerItem4 = QtWidgets.QSpacerItem(40, 25, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem4)
        self.btnUndo.raise_()
        self.btnRedo.raise_()
        self.btnLoadFile.raise_()
        self.btnSave.raise_()
        self.btnViewCode.raise_()
        self.btnQuickScreenshot.raise_()
        self.btnDrawAxes.raise_()
        self.btnDrawGrid.raise_()
        self.btnSetZoom.raise_()
        self.btnPanCenter.raise_()
        self.btnResetPan.raise_()
        self.btnAlignX.raise_()
        self.btnAlignY.raise_()
        self.btnPan.raise_()
        self.btnTranslate.raise_()
        self.btnScale.raise_()
        self.btnCustTransform.raise_()
        self.btnSendBackwards.raise_()
        self.btnSendForwards.raise_()
        self.comboAnchor.raise_()
        self.btnToggleVisible.raise_()
        self.btnAnchor.raise_()
        self.btnRotate.raise_()
        self.btnSelectEdit.raise_()
        self.btnDeleteMode.raise_()
        self.verticalLayout.addWidget(self.menuFrame)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(4)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSpacing(3)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.addOption = QtWidgets.QHBoxLayout()
        self.addOption.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.addOption.setContentsMargins(6, -1, -1, 0)
        self.addOption.setSpacing(6)
        self.addOption.setObjectName("addOption")
        self.btnFill = QtWidgets.QPushButton(self.mainWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnFill.sizePolicy().hasHeightForWidth())
        self.btnFill.setSizePolicy(sizePolicy)
        self.btnFill.setMaximumSize(QtCore.QSize(32, 32))
        self.btnFill.setBaseSize(QtCore.QSize(32, 32))
        self.btnFill.setAutoFillBackground(False)
        self.btnFill.setStyleSheet("")
        self.btnFill.setText("")
        icon22 = QtGui.QIcon()
        icon22.addPixmap(QtGui.QPixmap(":/icons/bucket.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        icon22.addPixmap(QtGui.QPixmap(":/icons/filledbucket.svg"), QtGui.QIcon.Normal, QtGui.QIcon.On)
        self.btnFill.setIcon(icon22)
        self.btnFill.setIconSize(QtCore.QSize(16, 16))
        self.btnFill.setCheckable(True)
        self.btnFill.setDefault(False)
        self.btnFill.setFlat(True)
        self.btnFill.setObjectName("btnFill")
        self.addOption.addWidget(self.btnFill)
        self.addOptionLayout = QtWidgets.QGridLayout()
        self.addOptionLayout.setSpacing(6)
        self.addOptionLayout.setObjectName("addOptionLayout")
        self.addOption.addLayout(self.addOptionLayout)
        spacerItem5 = QtWidgets.QSpacerItem(40, 35, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.addOption.addItem(spacerItem5)
        self.label = QtWidgets.QLabel(self.mainWidget)
        self.label.setObjectName("label")
        self.addOption.addWidget(self.label)
        self.txtLineWidth = QtWidgets.QLineEdit(self.mainWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtLineWidth.sizePolicy().hasHeightForWidth())
        self.txtLineWidth.setSizePolicy(sizePolicy)
        self.txtLineWidth.setMaximumSize(QtCore.QSize(75, 16777215))
        self.txtLineWidth.setObjectName("txtLineWidth")
        self.addOption.addWidget(self.txtLineWidth)
        self.frameCurrColor = QtWidgets.QFrame(self.mainWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frameCurrColor.sizePolicy().hasHeightForWidth())
        self.frameCurrColor.setSizePolicy(sizePolicy)
        self.frameCurrColor.setMinimumSize(QtCore.QSize(15, 15))
        self.frameCurrColor.setAutoFillBackground(False)
        self.frameCurrColor.setStyleSheet("QFrame{ \n"
"padding: 4.0;\n"
"border-radius: 3.0; \n"
"background: rgb(0, 0, 0)\n"
"}")
        self.frameCurrColor.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frameCurrColor.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.frameCurrColor.setObjectName("frameCurrColor")
        self.addOption.addWidget(self.frameCurrColor)
        self.btnSelectColor = QtWidgets.QPushButton(self.mainWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnSelectColor.sizePolicy().hasHeightForWidth())
        self.btnSelectColor.setSizePolicy(sizePolicy)
        self.btnSelectColor.setMaximumSize(QtCore.QSize(25, 25))
        self.btnSelectColor.setBaseSize(QtCore.QSize(32, 32))
        self.btnSelectColor.setAutoFillBackground(False)
        self.btnSelectColor.setStyleSheet("")
        self.btnSelectColor.setText("")
        icon23 = QtGui.QIcon()
        icon23.addPixmap(QtGui.QPixmap(":/icons/android-color-palette.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnSelectColor.setIcon(icon23)
        self.btnSelectColor.setIconSize(QtCore.QSize(16, 16))
        self.btnSelectColor.setDefault(False)
        self.btnSelectColor.setFlat(True)
        self.btnSelectColor.setObjectName("btnSelectColor")
        self.addOption.addWidget(self.btnSelectColor)
        self.verticalLayout_2.addLayout(self.addOption)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setContentsMargins(-1, 6, -1, -1)
        self.horizontalLayout_7.setSpacing(6)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.formFrame = QtWidgets.QFrame(self.mainWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.formFrame.sizePolicy().hasHeightForWidth())
        self.formFrame.setSizePolicy(sizePolicy)
        self.formFrame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.formFrame.setFrameShadow(QtWidgets.QFrame.Plain)
        self.formFrame.setLineWidth(0)
        self.formFrame.setObjectName("formFrame")
        self.formLayout = QtWidgets.QFormLayout(self.formFrame)
        self.formLayout.setContentsMargins(0, 0, 0, 0)
        self.formLayout.setSpacing(0)
        self.formLayout.setObjectName("formLayout")
        self.btnOpenPoly = QtWidgets.QPushButton(self.formFrame)
        self.btnOpenPoly.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnOpenPoly.sizePolicy().hasHeightForWidth())
        self.btnOpenPoly.setSizePolicy(sizePolicy)
        self.btnOpenPoly.setMaximumSize(QtCore.QSize(32, 32))
        self.btnOpenPoly.setText("")
        icon24 = QtGui.QIcon()
        icon24.addPixmap(QtGui.QPixmap(":/icons/openpolygon.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnOpenPoly.setIcon(icon24)
        self.btnOpenPoly.setIconSize(QtCore.QSize(16, 16))
        self.btnOpenPoly.setCheckable(True)
        self.btnOpenPoly.setFlat(True)
        self.btnOpenPoly.setObjectName("btnOpenPoly")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.btnOpenPoly)
        self.btnClosedPoly = QtWidgets.QPushButton(self.formFrame)
        self.btnClosedPoly.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnClosedPoly.sizePolicy().hasHeightForWidth())
        self.btnClosedPoly.setSizePolicy(sizePolicy)
        self.btnClosedPoly.setMaximumSize(QtCore.QSize(32, 32))
        self.btnClosedPoly.setText("")
        icon25 = QtGui.QIcon()
        icon25.addPixmap(QtGui.QPixmap(":/icons/closedpolygon.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnClosedPoly.setIcon(icon25)
        self.btnClosedPoly.setIconSize(QtCore.QSize(16, 16))
        self.btnClosedPoly.setCheckable(True)
        self.btnClosedPoly.setFlat(True)
        self.btnClosedPoly.setObjectName("btnClosedPoly")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.btnClosedPoly)
        self.btnOpenCurve = QtWidgets.QPushButton(self.formFrame)
        self.btnOpenCurve.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnOpenCurve.sizePolicy().hasHeightForWidth())
        self.btnOpenCurve.setSizePolicy(sizePolicy)
        self.btnOpenCurve.setMaximumSize(QtCore.QSize(32, 32))
        self.btnOpenCurve.setText("")
        icon26 = QtGui.QIcon()
        icon26.addPixmap(QtGui.QPixmap(":/icons/opencurve.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnOpenCurve.setIcon(icon26)
        self.btnOpenCurve.setIconSize(QtCore.QSize(16, 16))
        self.btnOpenCurve.setCheckable(True)
        self.btnOpenCurve.setFlat(True)
        self.btnOpenCurve.setObjectName("btnOpenCurve")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.btnOpenCurve)
        self.btnClosedCurve = QtWidgets.QPushButton(self.formFrame)
        self.btnClosedCurve.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnClosedCurve.sizePolicy().hasHeightForWidth())
        self.btnClosedCurve.setSizePolicy(sizePolicy)
        self.btnClosedCurve.setMaximumSize(QtCore.QSize(32, 32))
        self.btnClosedCurve.setText("")
        icon27 = QtGui.QIcon()
        icon27.addPixmap(QtGui.QPixmap(":/icons/closedcurve.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnClosedCurve.setIcon(icon27)
        self.btnClosedCurve.setIconSize(QtCore.QSize(16, 16))
        self.btnClosedCurve.setCheckable(True)
        self.btnClosedCurve.setFlat(True)
        self.btnClosedCurve.setObjectName("btnClosedCurve")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.btnClosedCurve)
        self.btnAddPoly = QtWidgets.QPushButton(self.formFrame)
        self.btnAddPoly.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnAddPoly.sizePolicy().hasHeightForWidth())
        self.btnAddPoly.setSizePolicy(sizePolicy)
        self.btnAddPoly.setMaximumSize(QtCore.QSize(32, 32))
        self.btnAddPoly.setText("")
        icon28 = QtGui.QIcon()
        icon28.addPixmap(QtGui.QPixmap(":/icons/triangle-stroked-15.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnAddPoly.setIcon(icon28)
        self.btnAddPoly.setIconSize(QtCore.QSize(16, 16))
        self.btnAddPoly.setCheckable(True)
        self.btnAddPoly.setFlat(True)
        self.btnAddPoly.setObjectName("btnAddPoly")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.btnAddPoly)
        self.btnAddCircle = QtWidgets.QPushButton(self.formFrame)
        self.btnAddCircle.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnAddCircle.sizePolicy().hasHeightForWidth())
        self.btnAddCircle.setSizePolicy(sizePolicy)
        self.btnAddCircle.setMaximumSize(QtCore.QSize(32, 32))
        self.btnAddCircle.setText("")
        icon29 = QtGui.QIcon()
        icon29.addPixmap(QtGui.QPixmap(":/icons/circle.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnAddCircle.setIcon(icon29)
        self.btnAddCircle.setIconSize(QtCore.QSize(16, 16))
        self.btnAddCircle.setCheckable(True)
        self.btnAddCircle.setFlat(True)
        self.btnAddCircle.setObjectName("btnAddCircle")
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.LabelRole, self.btnAddCircle)
        self.btnAddLabel = QtWidgets.QPushButton(self.formFrame)
        self.btnAddLabel.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnAddLabel.sizePolicy().hasHeightForWidth())
        self.btnAddLabel.setSizePolicy(sizePolicy)
        self.btnAddLabel.setMaximumSize(QtCore.QSize(32, 32))
        self.btnAddLabel.setText("")
        icon30 = QtGui.QIcon()
        icon30.addPixmap(QtGui.QPixmap(":/icons/text.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnAddLabel.setIcon(icon30)
        self.btnAddLabel.setIconSize(QtCore.QSize(16, 16))
        self.btnAddLabel.setCheckable(True)
        self.btnAddLabel.setFlat(True)
        self.btnAddLabel.setObjectName("btnAddLabel")
        self.formLayout.setWidget(11, QtWidgets.QFormLayout.LabelRole, self.btnAddLabel)
        self.btnAddFreehand = QtWidgets.QPushButton(self.formFrame)
        self.btnAddFreehand.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnAddFreehand.sizePolicy().hasHeightForWidth())
        self.btnAddFreehand.setSizePolicy(sizePolicy)
        self.btnAddFreehand.setMaximumSize(QtCore.QSize(32, 32))
        self.btnAddFreehand.setText("")
        icon31 = QtGui.QIcon()
        icon31.addPixmap(QtGui.QPixmap(":/icons/brush.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnAddFreehand.setIcon(icon31)
        self.btnAddFreehand.setIconSize(QtCore.QSize(16, 16))
        self.btnAddFreehand.setCheckable(True)
        self.btnAddFreehand.setFlat(True)
        self.btnAddFreehand.setObjectName("btnAddFreehand")
        self.formLayout.setWidget(12, QtWidgets.QFormLayout.LabelRole, self.btnAddFreehand)
        self.horizontalLayout_7.addWidget(self.formFrame)
        self.imgFrame = QtWidgets.QFrame(self.mainWidget)
        self.imgFrame.setMinimumSize(QtCore.QSize(0, 6))
        self.imgFrame.setMouseTracking(True)
        self.imgFrame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.imgFrame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.imgFrame.setObjectName("imgFrame")
        self.gridLayout = QtWidgets.QGridLayout(self.imgFrame)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.imgLabel = QtWidgets.QLabel(self.imgFrame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.imgLabel.sizePolicy().hasHeightForWidth())
        self.imgLabel.setSizePolicy(sizePolicy)
        self.imgLabel.setMouseTracking(True)
        self.imgLabel.setFrameShape(QtWidgets.QFrame.Panel)
        self.imgLabel.setText("")
        self.imgLabel.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.imgLabel.setObjectName("imgLabel")
        self.gridLayout.addWidget(self.imgLabel, 0, 1, 1, 1)
        self.horizontalLayout_7.addWidget(self.imgFrame)
        self.verticalLayout_2.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayout_3.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_3.setSpacing(0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.btnTogglePython = QtWidgets.QPushButton(self.mainWidget)
        self.btnTogglePython.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnTogglePython.sizePolicy().hasHeightForWidth())
        self.btnTogglePython.setSizePolicy(sizePolicy)
        self.btnTogglePython.setText("")
        icon32 = QtGui.QIcon()
        icon32.addPixmap(QtGui.QPixmap(":/icons/social-python.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnTogglePython.setIcon(icon32)
        self.btnTogglePython.setIconSize(QtCore.QSize(16, 16))
        self.btnTogglePython.setCheckable(True)
        self.btnTogglePython.setFlat(True)
        self.btnTogglePython.setObjectName("btnTogglePython")
        self.horizontalLayout_3.addWidget(self.btnTogglePython)
        self.txtTerminalPrompt = QtWidgets.QLineEdit(self.mainWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txtTerminalPrompt.sizePolicy().hasHeightForWidth())
        self.txtTerminalPrompt.setSizePolicy(sizePolicy)
        self.txtTerminalPrompt.setObjectName("txtTerminalPrompt")
        self.horizontalLayout_3.addWidget(self.txtTerminalPrompt)
        self.btnEnterCommand = QtWidgets.QPushButton(self.mainWidget)
        self.btnEnterCommand.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnEnterCommand.sizePolicy().hasHeightForWidth())
        self.btnEnterCommand.setSizePolicy(sizePolicy)
        self.btnEnterCommand.setText("")
        icon33 = QtGui.QIcon()
        icon33.addPixmap(QtGui.QPixmap(":/icons/subdirectory-left.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnEnterCommand.setIcon(icon33)
        self.btnEnterCommand.setIconSize(QtCore.QSize(16, 16))
        self.btnEnterCommand.setFlat(True)
        self.btnEnterCommand.setObjectName("btnEnterCommand")
        self.horizontalLayout_3.addWidget(self.btnEnterCommand)
        self.verticalLayout_2.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_2.addLayout(self.verticalLayout_2)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_4.addWidget(self.mainWidget)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1000, 26))
        self.menubar.setObjectName("menubar")
        self.menuFIle = QtWidgets.QMenu(self.menubar)
        self.menuFIle.setObjectName("menuFIle")
        self.menuOpenRecent = QtWidgets.QMenu(self.menuFIle)
        self.menuOpenRecent.setObjectName("menuOpenRecent")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menuOptions = QtWidgets.QMenu(self.menubar)
        self.menuOptions.setObjectName("menuOptions")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuTools = QtWidgets.QMenu(self.menubar)
        self.menuTools.setObjectName("menuTools")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setSizeGripEnabled(False)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionManual = QtWidgets.QAction(MainWindow)
        self.actionManual.setObjectName("actionManual")
        self.actionSettings = QtWidgets.QAction(MainWindow)
        self.actionSettings.setObjectName("actionSettings")
        self.actionPause = QtWidgets.QAction(MainWindow)
        self.actionPause.setObjectName("actionPause")
        self.actionSaveAs = QtWidgets.QAction(MainWindow)
        self.actionSaveAs.setObjectName("actionSaveAs")
        self.actionEnterCommand = QtWidgets.QAction(MainWindow)
        self.actionEnterCommand.setObjectName("actionEnterCommand")
        self.actionQuit = QtWidgets.QAction(MainWindow)
        self.actionQuit.setObjectName("actionQuit")
        self.actionUndo = QtWidgets.QAction(MainWindow)
        self.actionUndo.setEnabled(False)
        self.actionUndo.setObjectName("actionUndo")
        self.actionRedo = QtWidgets.QAction(MainWindow)
        self.actionRedo.setEnabled(False)
        self.actionRedo.setObjectName("actionRedo")
        self.actionShow_Grid = QtWidgets.QAction(MainWindow)
        self.actionShow_Grid.setObjectName("actionShow_Grid")
        self.actionShow_Local_Grid = QtWidgets.QAction(MainWindow)
        self.actionShow_Local_Grid.setObjectName("actionShow_Local_Grid")
        self.actionTransform = QtWidgets.QAction(MainWindow)
        self.actionTransform.setObjectName("actionTransform")
        self.actionExportAsymptote = QtWidgets.QAction(MainWindow)
        self.actionExportAsymptote.setObjectName("actionExportAsymptote")
        self.actionSave = QtWidgets.QAction(MainWindow)
        self.actionSave.setObjectName("actionSave")
        self.actionOpen = QtWidgets.QAction(MainWindow)
        self.actionOpen.setObjectName("actionOpen")
        self.actionClearRecent = QtWidgets.QAction(MainWindow)
        self.actionClearRecent.setObjectName("actionClearRecent")
        self.actionNewFile = QtWidgets.QAction(MainWindow)
        self.actionNewFile.setObjectName("actionNewFile")
        self.actionExportToAsy = QtWidgets.QAction(MainWindow)
        self.actionExportToAsy.setObjectName("actionExportToAsy")
        self.actionKeymaps = QtWidgets.QAction(MainWindow)
        self.actionKeymaps.setObjectName("actionKeymaps")
        self.menuOpenRecent.addSeparator()
        self.menuOpenRecent.addAction(self.actionClearRecent)
        self.menuFIle.addAction(self.actionNewFile)
        self.menuFIle.addAction(self.actionOpen)
        self.menuFIle.addAction(self.menuOpenRecent.menuAction())
        self.menuFIle.addAction(self.actionSave)
        self.menuFIle.addAction(self.actionSaveAs)
        self.menuFIle.addAction(self.actionExportToAsy)
        self.menuFIle.addAction(self.actionExportAsymptote)
        self.menuFIle.addSeparator()
        self.menuFIle.addAction(self.actionQuit)
        self.menuEdit.addAction(self.actionUndo)
        self.menuEdit.addAction(self.actionRedo)
        self.menuEdit.addSeparator()
        self.menuOptions.addAction(self.actionSettings)
        self.menuOptions.addAction(self.actionKeymaps)
        self.menuHelp.addAction(self.actionManual)
        self.menuHelp.addAction(self.actionAbout)
        self.menuTools.addAction(self.actionEnterCommand)
        self.menubar.addAction(self.menuFIle.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuOptions.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        self.comboAnchor.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "xasy"))
        self.btnUndo.setToolTip(_translate("MainWindow", "Undo"))
        self.btnRedo.setToolTip(_translate("MainWindow", "Redo"))
        self.btnLoadFile.setToolTip(_translate("MainWindow", "<html><head/><body><p>Open file</p></body></html>"))
        self.btnSave.setToolTip(_translate("MainWindow", "<html><head/><body><p>Save file</p></body></html>"))
        self.btnViewCode.setToolTip(_translate("MainWindow", "<html><head/><body><p>Edit code</p></body></html>"))
        self.btnQuickScreenshot.setToolTip(_translate("MainWindow", "<html><head/><body><p>Screenshot</p></body></html>"))
        self.btnDrawAxes.setToolTip(_translate("MainWindow", "<html><head/><body><p>Toggle display axes</p></body></html>"))
        self.btnDrawGrid.setToolTip(_translate("MainWindow", "<html><head/><body><p>Toggle grid</p></body></html>"))
        self.btnSetZoom.setToolTip(_translate("MainWindow", "Zoom"))
        self.btnPanCenter.setToolTip(_translate("MainWindow", "<html><head/><body><p>Center</p></body></html>"))
        self.btnResetPan.setToolTip(_translate("MainWindow", "<html><head/><body><p>Center about origin</p></body></html>"))
        self.btnAlignX.setToolTip(_translate("MainWindow", "<html><head/><body><p>Lock transform to X axis</p></body></html>"))
        self.btnAlignX.setText(_translate("MainWindow", "X"))
        self.btnAlignY.setToolTip(_translate("MainWindow", "<html><head/><body><p>Lock transform to Y axis</p></body></html>"))
        self.btnAlignY.setText(_translate("MainWindow", "Y"))
        self.btnSelectEdit.setToolTip(_translate("MainWindow", "<html><head/><body><p>Bézier editor</p></body></html>"))
        self.btnDeleteMode.setToolTip(_translate("MainWindow", "<html><head/><body><p>Delete</p></body></html>"))
        self.btnPan.setToolTip(_translate("MainWindow", "Pan"))
        self.btnTranslate.setToolTip(_translate("MainWindow", "Translate"))
        self.btnScale.setToolTip(_translate("MainWindow", "Scale"))
        self.btnRotate.setToolTip(_translate("MainWindow", "Rotate"))
        self.btnAnchor.setToolTip(_translate("MainWindow", "<html><head/><body><p>Set custom anchor</p></body></html>"))
        self.comboAnchor.setToolTip(_translate("MainWindow", "<html><head/><body><p>Anchor</p></body></html>"))
        self.comboAnchor.setCurrentText(_translate("MainWindow", "Center"))
        self.comboAnchor.setItemText(0, _translate("MainWindow", "Center"))
        self.comboAnchor.setItemText(1, _translate("MainWindow", "Origin"))
        self.comboAnchor.setItemText(2, _translate("MainWindow", "Top Left"))
        self.comboAnchor.setItemText(3, _translate("MainWindow", "Top Right"))
        self.comboAnchor.setItemText(4, _translate("MainWindow", "Bottom Right"))
        self.comboAnchor.setItemText(5, _translate("MainWindow", "Bottom Left"))
        self.comboAnchor.setItemText(6, _translate("MainWindow", "Custom"))
        self.btnCustTransform.setToolTip(_translate("MainWindow", "<html><head/><body><p><br/></p></body></html>"))
        self.btnSendBackwards.setToolTip(_translate("MainWindow", "<html><head/><body><p><br/></p></body></html>"))
        self.btnSendForwards.setToolTip(_translate("MainWindow", "Translate"))
        self.btnFill.setToolTip(_translate("MainWindow", "<html><head/><body><p>Toggle fill/outline</p></body></html>"))
        self.label.setText(_translate("MainWindow", "Line Width:"))
        self.txtLineWidth.setToolTip(_translate("MainWindow", "<html><head/><body><p>Current pen width</p></body></html>"))
        self.frameCurrColor.setToolTip(_translate("MainWindow", "<html><head/><body><p>Current pen color</p></body></html>"))
        self.btnSelectColor.setToolTip(_translate("MainWindow", "<html><head/><body><p>Set color</p></body></html>"))
        self.btnOpenPoly.setToolTip(_translate("MainWindow", "<html><head/><body><p>Open polygon</p></body></html>"))
        self.btnClosedPoly.setToolTip(_translate("MainWindow", "<html><head/><body><p>Closed polygon</p></body></html>"))
        self.btnOpenCurve.setToolTip(_translate("MainWindow", "<html><head/><body><p>Open Bézier curve</p></body></html>"))
        self.btnClosedCurve.setToolTip(_translate("MainWindow", "<html><head/><body><p>Closed Bézier curve</p></body></html>"))
        self.btnAddPoly.setToolTip(_translate("MainWindow", "<html><head/><body><p>Regular polygon</p></body></html>"))
        self.btnAddCircle.setToolTip(_translate("MainWindow", "<html><head/><body><p>Circle</p></body></html>"))
        self.btnAddLabel.setToolTip(_translate("MainWindow", "<html><head/><body><p>Text</p></body></html>"))
        self.btnAddFreehand.setToolTip(_translate("MainWindow", "<html><head/><body><p>Freehand</p></body></html>"))
        self.menuFIle.setTitle(_translate("MainWindow", "&File"))
        self.menuOpenRecent.setTitle(_translate("MainWindow", "Open Recent"))
        self.menuEdit.setTitle(_translate("MainWindow", "&Edit"))
        self.menuOptions.setTitle(_translate("MainWindow", "Optio&ns"))
        self.menuHelp.setTitle(_translate("MainWindow", "&Help"))
        self.menuTools.setTitle(_translate("MainWindow", "&Tools"))
        self.actionAbout.setText(_translate("MainWindow", "&About"))
        self.actionManual.setText(_translate("MainWindow", "&Manual"))
        self.actionSettings.setText(_translate("MainWindow", "&Settings"))
        self.actionPause.setText(_translate("MainWindow", "Pause "))
        self.actionSaveAs.setText(_translate("MainWindow", "&Save as"))
        self.actionEnterCommand.setText(_translate("MainWindow", "&Enter Command"))
        self.actionQuit.setText(_translate("MainWindow", "&Quit"))
        self.actionUndo.setText(_translate("MainWindow", "&Undo"))
        self.actionRedo.setText(_translate("MainWindow", "&Redo"))
        self.actionShow_Grid.setText(_translate("MainWindow", "&Show Grid"))
        self.actionShow_Local_Grid.setText(_translate("MainWindow", "Show &Local Grid"))
        self.actionTransform.setText(_translate("MainWindow", "&Transform"))
        self.actionExportAsymptote.setText(_translate("MainWindow", "Export as..."))
        self.actionSave.setText(_translate("MainWindow", "Save"))
        self.actionOpen.setText(_translate("MainWindow", "Open"))
        self.actionClearRecent.setText(_translate("MainWindow", "Clear Menu"))
        self.actionNewFile.setText(_translate("MainWindow", "New File"))
        self.actionExportToAsy.setText(_translate("MainWindow", "Export as Asy"))
        self.actionKeymaps.setText(_translate("MainWindow", "&Keymaps"))
from xasyicons import icons_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'windows/widg_editBezier.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.setWindowModality(QtCore.Qt.NonModal)
        Form.resize(692, 35)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        Form.setMinimumSize(QtCore.QSize(0, 35))
        Form.setMaximumSize(QtCore.QSize(16777215, 35))
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.cmbLockMode = QtWidgets.QComboBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cmbLockMode.sizePolicy().hasHeightForWidth())
        self.cmbLockMode.setSizePolicy(sizePolicy)
        self.cmbLockMode.setObjectName("cmbLockMode")
        self.cmbLockMode.addItem("")
        self.cmbLockMode.addItem("")
        self.cmbLockMode.addItem("")
        self.horizontalLayout.addWidget(self.cmbLockMode)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.chkRecompute = QtWidgets.QCheckBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.chkRecompute.sizePolicy().hasHeightForWidth())
        self.chkRecompute.setSizePolicy(sizePolicy)
        self.chkRecompute.setObjectName("chkRecompute")
        self.horizontalLayout.addWidget(self.chkRecompute)
        self.btnForceRecompute = QtWidgets.QPushButton(Form)
        self.btnForceRecompute.setObjectName("btnForceRecompute")
        self.horizontalLayout.addWidget(self.btnForceRecompute)
        self.btnOk = QtWidgets.QPushButton(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnOk.sizePolicy().hasHeightForWidth())
        self.btnOk.setSizePolicy(sizePolicy)
        self.btnOk.setMaximumSize(QtCore.QSize(25, 25))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/check.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnOk.setIcon(icon)
        self.btnOk.setFlat(True)
        self.btnOk.setObjectName("btnOk")
        self.horizontalLayout.addWidget(self.btnOk)
        self.btnCancel = QtWidgets.QPushButton(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnCancel.sizePolicy().hasHeightForWidth())
        self.btnCancel.setSizePolicy(sizePolicy)
        self.btnCancel.setMaximumSize(QtCore.QSize(25, 25))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/close-round.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnCancel.setIcon(icon1)
        self.btnCancel.setFlat(True)
        self.btnCancel.setObjectName("btnCancel")
        self.horizontalLayout.addWidget(self.btnCancel)
        self.horizontalLayout_2.addLayout(self.horizontalLayout)

        self.retranslateUi(Form)
        self.cmbLockMode.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.cmbLockMode.setItemText(0, _translate("Form", "No Lock"))
        self.cmbLockMode.setItemText(1, _translate("Form", "Lock Angle"))
        self.cmbLockMode.setItemText(2, _translate("Form", "Lock Angle & Scale"))
        self.chkRecompute.setText(_translate("Form", "Recompute Path"))
        self.btnForceRecompute.setText(_translate("Form", "Recompute Once"))
from xasyicons import icons_rc



#!/usr/bin/env python3

from xasyqtui.widg_editBezier import Ui_Form

import PyQt5.QtWidgets as QtWidgets
import PyQt5.QtCore as QtCore

class LockMode:
    noLock = 0
    angleLock = 1
    angleAndScaleLock = 2

class Widg_editBezier(QtWidgets.QWidget):
    def __init__(self, info: dict, enableCurveFeatures: bool=True):
        super().__init__()
        self.ui = Ui_Form()
        self.ui.setupUi(self)
        self.info = info

        self.ui.chkRecompute.setChecked(self.info['autoRecompute'])
        self.ui.cmbLockMode.setCurrentIndex(self.info['editBezierlockMode'])

        self.ui.cmbLockMode.currentIndexChanged[int].connect(self.cmbLockIndexChange)
        self.ui.chkRecompute.stateChanged.connect(self.chkRecomputeChanged)

        self.disableOnAutoRecompute = {self.ui.cmbLockMode, self.ui.btnForceRecompute}
        self.curveBtnsOnly = {self.ui.cmbLockMode, self.ui.btnForceRecompute, self.ui.chkRecompute}

        for elem in self.curveBtnsOnly:
            elem.setEnabled(enableCurveFeatures)

    @property
    def autoRecompute(self) -> bool:
        return self.ui.chkRecompute.isChecked()

    @property
    def lockMode(self) -> int:
        return self.ui.cmbLockMode.currentIndex()

    @QtCore.pyqtSlot(int)
    def cmbLockIndexChange(self, index: int):
        self.info['editBezierlockMode'] = index

    @QtCore.pyqtSlot(int)
    def chkRecomputeChanged(self, checked: int):
        isChecked = (checked == 2)
        for obj in self.disableOnAutoRecompute:
            obj.setEnabled(not checked)
        self.info['autoRecompute'] = checked

        if isChecked:
            self.ui.btnForceRecompute.clicked.emit()



#!/usr/bin/env python3
import PyQt5.QtGui as QtGui
import PyQt5.QtCore as QtCore
import numpy as numpy

class Guide:
    def __init__(self, pen=None):
        if pen is None:
            pen = QtGui.QPen()
        assert isinstance(pen, QtGui.QPen)
        self.pen = pen

    def drawShape(self, pen):
        assert isinstance(pen, QtGui.QPainter)
        pen.save()
        pen.setPen(self.pen)

class LineGuide(Guide):
    def __init__(self, origin, direction, pen=None):
        super().__init__(pen)
        self.origin = origin
        self.direction = direction

    def drawShape(self, pen):
        super().drawShape(pen)
        p1 = self.origin + (9999 * QtCore.QPointF(numpy.cos(self.direction), numpy.sin(self.direction)))
        p2 = self.origin - (9999 * QtCore.QPointF(numpy.cos(self.direction), numpy.sin(self.direction)))
        pen.drawLine(QtCore.QLineF(p1, p2))
        pen.restore()

class ArcGuide(Guide):
    @classmethod
    def radTo16Deg(cls, radians):
        return int(round(numpy.rad2deg(radians) * 16))

    def __init__(self, center=None, radius=1, startAng=0, endAng=(2*numpy.pi), pen=None):
        if center is None:
            center = QtCore.QPointF(0, 0)
        super().__init__(pen)
        self.center = center
        self.radius = int(radius)
        self.startAng = startAng
        self.endAng = endAng

    def drawShape(self, pen):
        super().drawShape(pen)
        assert isinstance(pen, QtGui.QPainter)
        x, y = int(round(self.center.x())), int(round(self.center.y()))
        pen.drawArc(x - self.radius, y - self.radius, 2 * self.radius, 2 * self.radius, ArcGuide.radTo16Deg(self.startAng),
                    -ArcGuide.radTo16Deg(self.endAng - self.startAng))
        pen.restore()
